MN 61 The Exhortation to Rāhula at Mango Stone | Ambalaṭṭhikā Rāhulovāda Sutta | sutta on dhammatalks.org
Description: Theravada Buddhist Sutta from the Pāli Canon

Skip to main content

# The Exhortation to Rāhula at Mango Stone
Ambalaṭṭhikā Rāhulovāda Sutta (MN 61)

I have heard that on one occasion the Blessed One was staying near Rājagaha, in the Bamboo Forest, the Squirrels’ Sanctuary.

At that time Ven. Rāhula1 was staying at the Mango Stone. Then the Blessed One, emerging from his seclusion in the evening, went to where Ven. Rāhula was staying at the Mango Stone. Ven. Rāhula saw him coming from afar and, on seeing him, set out a seat & water for washing the feet. The Blessed One sat down on the seat set out and, having sat down, washed his feet. Ven. Rāhula, bowing down to the Blessed One, sat to one side.

Then the Blessed One, having left a little bit of the remaining water in the water dipper, said to Ven. Rāhula, “Rāhula, do you see this little bit of remaining water left in the water dipper?”

“Yes sir.”

“That’s how little of a contemplative2 there is in anyone who feels no shame at telling a deliberate lie.”

Having tossed away the little bit of remaining water, the Blessed One said to Ven. Rāhula, “Rāhula, do you see how this little bit of remaining water is tossed away?”

“Yes, sir.”

“Rāhula, whatever there is of a contemplative in anyone who feels no shame at telling a deliberate lie is tossed away just like that.”

Having turned the water dipper upside down, the Blessed One said to Ven. Rāhula, “Rāhula, do you see how this water dipper is turned upside down?”

“Yes, sir.”

“Rāhula, whatever there is of a contemplative in anyone who feels no shame at telling a deliberate lie is turned upside down just like that.”

Having turned the water dipper right-side up, the Blessed One said to Ven. Rāhula, “Rāhula, do you see how empty & hollow this water dipper is?”

“Yes, sir.”

“Rāhula, whatever there is of a contemplative in anyone who feels no shame at telling a deliberate lie is empty & hollow just like that.

“Rāhula, it’s like a royal elephant: immense, pedigreed, accustomed to battles, its tusks like chariot poles. Having gone into battle, it uses its forefeet & hindfeet, its forequarters & hindquarters, its head & ears & tusks & tail, but will simply hold back its trunk. The elephant trainer notices that and thinks, ‘This royal elephant has not given up its life to the king.’ But when the royal elephant… having gone into battle, uses its forefeet & hindfeet, its forequarters & hindquarters, its head & ears & tusks & tail & his trunk, the trainer notices that and thinks, ‘This royal elephant has given up its life to the king. There is nothing it will not do.’

“In the same way, Rāhula, when anyone feels no shame in telling a deliberate lie, there is no evil, I tell you, he will not do. Thus, Rāhula, you should train yourself, ‘I will not tell a deliberate lie even in jest.’

“What do you think, Rāhula? What is a mirror for?”

“For reflection, sir.”

“In the same way, Rāhula, bodily actions, verbal actions, & mental actions are to be done with repeated reflection.

“Whenever you want to do a bodily action, you should reflect on it: ‘This bodily action I want to do—would it lead to self-affliction, to the affliction of others, or to both? Would it be an unskillful bodily action, with painful consequences, painful results?’ If, on reflection, you know that it would lead to self-affliction, to the affliction of others, or to both; it would be an unskillful bodily action with painful consequences, painful results, then any bodily action of that sort is absolutely unfit for you to do. But if on reflection you know that it would not cause affliction… it would be a skillful bodily action with pleasant consequences, pleasant results, then any bodily action of that sort is fit for you to do.

“While you are doing a bodily action, you should reflect on it: ‘This bodily action I am doing—is it leading to self-affliction, to the affliction of others, or to both? Is it an unskillful bodily action, with painful consequences, painful results?’ If, on reflection, you know that it is leading to self-affliction, to affliction of others, or both… you should give it up. But if on reflection you know that it is not… you may continue with it.

“Having done a bodily action, you should reflect on it: ‘This bodily action I have done—did it lead to self-affliction, to the affliction of others, or to both? Was it an unskillful bodily action, with painful consequences, painful results?’ If, on reflection, you know that it led to self-affliction, to the affliction of others, or to both; it was an unskillful bodily action with painful consequences, painful results, then you should confess it, reveal it, lay it open to the Teacher or to an observant companion in the holy life. Having confessed it… you should exercise restraint in the future. But if on reflection you know that it did not lead to affliction… it was a skillful bodily action with pleasant consequences, pleasant results, then you should stay mentally refreshed & joyful, training day & night in skillful qualities.

“Whenever you want to do a verbal action, you should reflect on it: ‘This verbal action I want to do—would it lead to self-affliction, to the affliction of others, or to both? Would it be an unskillful verbal action, with painful consequences, painful results?’ If, on reflection, you know that it would lead to self-affliction, to the affliction of others, or to both; it would be an unskillful verbal action with painful consequences, painful results, then any verbal action of that sort is absolutely unfit for you to do. But if on reflection you know that it would not cause affliction… it would be a skillful verbal action with pleasant consequences, pleasant results, then any verbal action of that sort is fit for you to do.

“While you are doing a verbal action, you should reflect on it: ‘This verbal action I am doing—is it leading to self-affliction, to the affliction of others, or to both? Is it an unskillful verbal action, with painful consequences, painful results?’ If, on reflection, you know that it is leading to self-affliction, to affliction of others, or both… you should give it up. But if on reflection you know that it is not… you may continue with it.

“Having done a verbal action, you should reflect on it: ‘This verbal action I have done—did it lead to self-affliction, to the affliction of others, or to both? Was it an unskillful verbal action, with painful consequences, painful results?’ If, on reflection, you know that it led to self-affliction, to the affliction of others, or to both; it was an unskillful verbal action with painful consequences, painful results, then you should confess it, reveal it, lay it open to the Teacher or to an observant companion in the holy life. Having confessed it… you should exercise restraint in the future. But if on reflection you know that it did not lead to affliction… it was a skillful verbal action with pleasant consequences, pleasant results, then you should stay mentally refreshed & joyful, training day & night in skillful qualities.

“Whenever you want to do a mental action, you should reflect on it: ‘This mental action I want to do—would it lead to self-affliction, to the affliction of others, or to both? Would it be an unskillful mental action, with painful consequences, painful results?’ If, on reflection, you know that it would lead to self-affliction, to the affliction of others, or to both; it would be an unskillful mental action with painful consequences, painful results, then any mental action of that sort is absolutely unfit for you to do. But if on reflection you know that it would not cause affliction… it would be a skillful mental action with pleasant consequences, pleasant results, then any mental action of that sort is fit for you to do.

“While you are doing a mental action, you should reflect on it: ‘This mental action I am doing—is it leading to self-affliction, to the affliction of others, or to both? Is it an unskillful mental action, with painful consequences, painful results?’ If, on reflection, you know that it is leading to self-affliction, to affliction of others, or both… you should give it up. But if on reflection you know that it is not… you may continue with it.

“Having done a mental action, you should reflect on it: ‘This mental action I have done—did it lead to self-affliction, to the affliction of others, or to both? Was it an unskillful mental action, with painful consequences, painful results?’ If, on reflection, you know that it led to self-affliction, to the affliction of others, or to both; it was an unskillful mental action with painful consequences, painful results, then you should feel distressed, ashamed, & disgusted with it. Feeling distressed… you should exercise restraint in the future. But if on reflection you know that it did not lead to affliction… it was a skillful mental action with pleasant consequences, pleasant results, then you should stay mentally refreshed & joyful, training day & night in skillful qualities.

“Rāhula, all those contemplatives & brahmans in the course of the past who purified their bodily actions, verbal actions, & mental actions, did it through repeated reflection on their bodily actions, verbal actions, & mental actions in just this way.

“All those contemplatives & brahmans in the course of the future who will purify their bodily actions, verbal actions, & mental actions, will do it through repeated reflection on their bodily actions, verbal actions, & mental actions in just this way.

“All those contemplatives & brahmans at present who purify their bodily actions, verbal actions, & mental actions, do it through repeated reflection on their bodily actions, verbal actions, & mental actions in just this way.

“Thus, Rāhula, you should train yourself: ‘I will purify my bodily actions through repeated reflection. I will purify my verbal actions through repeated reflection. I will purify my mental actions through repeated reflection.’ That’s how you should train yourself.”

That is what the Blessed One said. Gratified, Ven. Rāhula delighted in the Blessed One’s words.

Notes

1. Rāhula: the Buddha’s son, who according to the Commentary was seven years old when this discourse was delivered to him.

2. Sāmañña. Throughout ancient cultures, the terminology of music was used to describe the moral quality of people and actions. Discordant intervals or poorly-tuned musical instruments were metaphors for evil; harmonious intervals and well-tuned instruments, metaphors for good. In Pali, the term sama—“even”—described an instrument tuned on-pitch. There is a famous passage (AN 6:55) where the Buddha reminds Soṇa Koḷivisa—who had been over-exerting himself in the practice—that a lute sounds appealing only if the strings are neither too taut nor too lax, but “evenly” tuned. This image would have special resonances with the Buddha's teaching on the middle way. It also adds meaning to the term samaṇa—monk or contemplative—which the texts frequently mention as being derived from sama. The word sāmañña—“evenness,” the quality of being in tune—also means the quality of being a contemplative: The true contemplative is always in tune with what is proper and good.

See also: MN 19; MN 24; MN 95; MN 121; AN 3:66; AN 4:115; AN 5:140; AN 7:80; AN 8:53; Iti 25